@@ -34,7 +34,8 @@ import org.apache.http.HttpResponse;
 import org.apache.http.HttpStatus;
 import org.apache.http.HttpVersion;
 import org.apache.http.ProtocolVersion;
-import static org.apache.http.impl.cookie.DateUtils.formatDate;
+import org.apache.http.client.methods.HttpOptions;
+import org.apache.http.client.utils.DateUtils;
 import org.apache.http.message.BasicHttpRequest;
 import org.apache.http.message.BasicHttpResponse;
 import org.apache.http.message.BasicStatusLine;
@@ -48,7 +49,7 @@ public class TestResponseCachingPolicy {
     private ResponseCachingPolicy policy;
     private HttpResponse response;
     private HttpRequest request;
-    private int[] acceptableCodes = new int[] { HttpStatus.SC_OK,
+    private final int[] acceptableCodes = new int[] { HttpStatus.SC_OK,
             HttpStatus.SC_NON_AUTHORITATIVE_INFORMATION, HttpStatus.SC_MULTIPLE_CHOICES,
             HttpStatus.SC_MOVED_PERMANENTLY, HttpStatus.SC_GONE };
     private Date now;
@@ -60,12 +61,12 @@ public class TestResponseCachingPolicy {
         now = new Date();
         sixSecondsAgo = new Date(now.getTime() - 6 * 1000L);
         tenSecondsFromNow = new Date(now.getTime() + 10 * 1000L);
-        
-        policy = new ResponseCachingPolicy(0, true);
+
+        policy = new ResponseCachingPolicy(0, true, false, false);
         request = new BasicHttpRequest("GET","/",HTTP_1_1);
         response = new BasicHttpResponse(
                 new BasicStatusLine(HTTP_1_1, HttpStatus.SC_OK, ""));
-        response.setHeader("Date", formatDate(new Date()));
+        response.setHeader("Date", DateUtils.formatDate(new Date()));
         response.setHeader("Content-Length", "0");
     }
 
@@ -83,7 +84,7 @@ public class TestResponseCachingPolicy {
 
     @Test
     public void testResponsesToRequestsWithAuthorizationHeadersAreCacheableByNonSharedCache() {
-        policy = new ResponseCachingPolicy(0, false);
+        policy = new ResponseCachingPolicy(0, false, false, false);
         request = new BasicHttpRequest("GET","/",HTTP_1_1);
         request.setHeader("Authorization","Basic dXNlcjpwYXNzd2Q=");
         Assert.assertTrue(policy.isResponseCacheable(request,response));
@@ -133,6 +134,16 @@ public class TestResponseCachingPolicy {
         Assert.assertFalse(policy.isResponseCacheable("GET", response));
     }
 
+    @Test
+    public void test206ResponseCodeIsNotCacheableUsingSharedPublicCache() {
+        policy = new ResponseCachingPolicy(0, true, false, false);
+
+        request.setHeader("Authorization", "Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==");
+        response.setStatusCode(HttpStatus.SC_PARTIAL_CONTENT);
+        response.setHeader("Cache-Control", "public");
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void test300ResponseCodeIsCacheable() {
         response.setStatusCode(HttpStatus.SC_MULTIPLE_CHOICES);
@@ -159,6 +170,24 @@ public class TestResponseCachingPolicy {
         Assert.assertFalse(policy.isResponseCacheable("GET", response));
     }
 
+    @Test
+    public void testPlain303ResponseCodeIsNotCacheableUnderDefaultBehavior() {
+        response.setStatusCode(HttpStatus.SC_SEE_OTHER);
+        response.removeHeaders("Expires");
+        response.removeHeaders("Cache-Control");
+        Assert.assertFalse(policy.isResponseCacheable("GET", response));
+    }
+
+    @Test
+    public void testPlain303ResponseCodeIsNotCacheableEvenIf303CachingEnabled() {
+        policy = new ResponseCachingPolicy(0, true, false, true);
+        response.setStatusCode(HttpStatus.SC_SEE_OTHER);
+        response.removeHeaders("Expires");
+        response.removeHeaders("Cache-Control");
+        Assert.assertFalse(policy.isResponseCacheable("GET", response));
+    }
+
+
     @Test
     public void testPlain307ResponseCodeIsNotCacheable() {
         response.setStatusCode(HttpStatus.SC_TEMPORARY_REDIRECT);
@@ -169,15 +198,15 @@ public class TestResponseCachingPolicy {
 
     @Test
     public void testNon206WithExplicitExpiresIsCacheable() {
-        int status = getRandomStatus();
+        final int status = getRandomStatus();
         response.setStatusCode(status);
-        response.setHeader("Expires", formatDate(new Date()));
+        response.setHeader("Expires", DateUtils.formatDate(new Date()));
         Assert.assertTrue(policy.isResponseCacheable("GET", response));
     }
 
     @Test
     public void testNon206WithMaxAgeIsCacheable() {
-        int status = getRandomStatus();
+        final int status = getRandomStatus();
         response.setStatusCode(status);
         response.setHeader("Cache-Control", "max-age=0");
         Assert.assertTrue(policy.isResponseCacheable("GET", response));
@@ -185,7 +214,7 @@ public class TestResponseCachingPolicy {
 
     @Test
     public void testNon206WithSMaxAgeIsCacheable() {
-        int status = getRandomStatus();
+        final int status = getRandomStatus();
         response.setStatusCode(status);
         response.setHeader("Cache-Control", "s-maxage=0");
         Assert.assertTrue(policy.isResponseCacheable("GET", response));
@@ -193,7 +222,7 @@ public class TestResponseCachingPolicy {
 
     @Test
     public void testNon206WithMustRevalidateIsCacheable() {
-        int status = getRandomStatus();
+        final int status = getRandomStatus();
         response.setStatusCode(status);
         response.setHeader("Cache-Control", "must-revalidate");
         Assert.assertTrue(policy.isResponseCacheable("GET", response));
@@ -201,7 +230,7 @@ public class TestResponseCachingPolicy {
 
     @Test
     public void testNon206WithProxyRevalidateIsCacheable() {
-        int status = getRandomStatus();
+        final int status = getRandomStatus();
         response.setStatusCode(status);
         response.setHeader("Cache-Control", "proxy-revalidate");
         Assert.assertTrue(policy.isResponseCacheable("GET", response));
@@ -209,7 +238,7 @@ public class TestResponseCachingPolicy {
 
     @Test
     public void testNon206WithPublicCacheControlIsCacheable() {
-        int status = getRandomStatus();
+        final int status = getRandomStatus();
         response.setStatusCode(status);
         response.setHeader("Cache-Control", "public");
         Assert.assertTrue(policy.isResponseCacheable("GET", response));
@@ -217,7 +246,7 @@ public class TestResponseCachingPolicy {
 
     @Test
     public void testNon206WithPrivateCacheControlIsNotCacheableBySharedCache() {
-        int status = getRandomStatus();
+        final int status = getRandomStatus();
         response.setStatusCode(status);
         response.setHeader("Cache-Control", "private");
         Assert.assertFalse(policy.isResponseCacheable("GET", response));
@@ -225,7 +254,7 @@ public class TestResponseCachingPolicy {
 
     @Test
     public void test200ResponseWithPrivateCacheControlIsCacheableByNonSharedCache() {
-        policy = new ResponseCachingPolicy(0, false);
+        policy = new ResponseCachingPolicy(0, false, false, false);
         response.setStatusCode(HttpStatus.SC_OK);
         response.setHeader("Cache-Control", "private");
         Assert.assertTrue(policy.isResponseCacheable("GET", response));
@@ -283,7 +312,7 @@ public class TestResponseCachingPolicy {
 
         response = new BasicHttpResponse(
                 new BasicStatusLine(HTTP_1_1, HttpStatus.SC_OK, ""));
-        response.setHeader("Date", formatDate(new Date()));
+        response.setHeader("Date", DateUtils.formatDate(new Date()));
         response.addHeader("Cache-Control", "no-transform");
         response.setHeader("Content-Length", "0");
 
@@ -309,6 +338,16 @@ public class TestResponseCachingPolicy {
         Assert.assertFalse(policy.isResponseCacheable("GET", response));
     }
 
+    @Test
+    public void testVaryStarIsNotCacheableUsingSharedPublicCache() {
+        policy = new ResponseCachingPolicy(0, true, false, false);
+
+        request.setHeader("Authorization", "Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==");
+        response.setHeader("Cache-Control", "public");
+        response.setHeader("Vary", "*");
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void testIsGetWithVaryHeaderCacheable() {
         response.addHeader("Vary", "Accept-Encoding");
@@ -323,6 +362,18 @@ public class TestResponseCachingPolicy {
         Assert.assertFalse(policy.isResponseCacheable("get", response));
     }
 
+    @Test
+    public void testIsArbitraryMethodCacheableUsingSharedPublicCache() {
+        policy = new ResponseCachingPolicy(0, true, false, false);
+
+        request = new HttpOptions("http://foo.example.com/");
+        request.setHeader("Authorization", "Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==");
+        response.setStatusCode(HttpStatus.SC_NO_CONTENT);
+        response.setHeader("Cache-Control", "public");
+
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void testResponsesToRequestsWithNoStoreAreNotCacheable() {
         request.setHeader("Cache-Control","no-store");
@@ -337,28 +388,73 @@ public class TestResponseCachingPolicy {
         Assert.assertFalse(policy.isResponseCacheable("GET", response));
     }
 
+    @Test
+    public void testResponsesWithMultipleAgeHeadersAreNotCacheableUsingSharedPublicCache() {
+        policy = new ResponseCachingPolicy(0, true, false, false);
+
+        request.setHeader("Authorization", "Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==");
+        response.setHeader("Cache-Control", "public");
+        response.addHeader("Age", "3");
+        response.addHeader("Age", "5");
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void testResponsesWithMultipleDateHeadersAreNotCacheable() {
-        response.addHeader("Date", formatDate(now));
-        response.addHeader("Date", formatDate(sixSecondsAgo));
+        response.addHeader("Date", DateUtils.formatDate(now));
+        response.addHeader("Date", DateUtils.formatDate(sixSecondsAgo));
         Assert.assertFalse(policy.isResponseCacheable("GET", response));
     }
 
+    @Test
+    public void testResponsesWithMultipleDateHeadersAreNotCacheableUsingSharedPublicCache() {
+        policy = new ResponseCachingPolicy(0, true, false, false);
+
+        request.setHeader("Authorization", "Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==");
+        response.setHeader("Cache-Control", "public");
+        response.addHeader("Date", DateUtils.formatDate(now));
+        response.addHeader("Date", DateUtils.formatDate(sixSecondsAgo));
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void testResponsesWithMalformedDateHeadersAreNotCacheable() {
         response.addHeader("Date", "garbage");
         Assert.assertFalse(policy.isResponseCacheable("GET", response));
     }
 
+    @Test
+    public void testResponsesWithMalformedDateHeadersAreNotCacheableUsingSharedPublicCache() {
+        policy = new ResponseCachingPolicy(0, true, false, false);
+
+        request.setHeader("Authorization", "Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==");
+        response.setHeader("Cache-Control", "public");
+        response.addHeader("Date", "garbage");
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void testResponsesWithMultipleExpiresHeadersAreNotCacheable() {
-        Date now = new Date();
-        Date sixSecondsAgo = new Date(now.getTime() - 6 * 1000L);
-        response.addHeader("Expires", formatDate(now));
-        response.addHeader("Expires", formatDate(sixSecondsAgo));
+        final Date now = new Date();
+        final Date sixSecondsAgo = new Date(now.getTime() - 6 * 1000L);
+        response.addHeader("Expires", DateUtils.formatDate(now));
+        response.addHeader("Expires", DateUtils.formatDate(sixSecondsAgo));
         Assert.assertFalse(policy.isResponseCacheable("GET", response));
     }
 
+    @Test
+    public void testResponsesWithMultipleExpiresHeadersAreNotCacheableUsingSharedPublicCache() {
+        policy = new ResponseCachingPolicy(0, true, false, false);
+
+        request.setHeader("Authorization", "Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==");
+        response.setHeader("Cache-Control", "public");
+        final Date now = new Date();
+        final Date sixSecondsAgo = new Date(now.getTime() - 6 * 1000L);
+        response.addHeader("Expires", DateUtils.formatDate(now));
+        response.addHeader("Expires", DateUtils.formatDate(sixSecondsAgo));
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void testResponsesWithoutDateHeadersAreNotCacheable() {
         response.removeHeaders("Date");
@@ -371,6 +467,16 @@ public class TestResponseCachingPolicy {
         Assert.assertFalse(policy.isResponseCacheable("GET", response));
     }
 
+    @Test
+    public void testResponseThatHasTooMuchContentIsNotCacheableUsingSharedPublicCache() {
+        policy = new ResponseCachingPolicy(0, true, false, false);
+
+        request.setHeader("Authorization", "Basic QWxhZGRpbjpvcGVuIHNlc2FtZQ==");
+        response.setHeader("Cache-Control", "public");
+        response.setHeader("Content-Length", "9000");
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void testResponsesThatAreSmallEnoughAreCacheable() {
         response.setHeader("Content-Length", "0");
@@ -383,11 +489,27 @@ public class TestResponseCachingPolicy {
         Assert.assertFalse(policy.isResponseCacheable(request, response));
     }
 
+    @Test
+    public void testResponsesToGETWithQueryParamsButNoExplicitCachingAreNotCacheableEvenWhen1_0QueryCachingDisabled() {
+        policy = new ResponseCachingPolicy(0, true, true, false);
+        request = new BasicHttpRequest("GET", "/foo?s=bar");
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void testResponsesToGETWithQueryParamsAndExplicitCachingAreCacheable() {
         request = new BasicHttpRequest("GET", "/foo?s=bar");
-        response.setHeader("Date", formatDate(now));
-        response.setHeader("Expires", formatDate(tenSecondsFromNow));
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(tenSecondsFromNow));
+        Assert.assertTrue(policy.isResponseCacheable(request, response));
+    }
+
+    @Test
+    public void testResponsesToGETWithQueryParamsAndExplicitCachingAreCacheableEvenWhen1_0QueryCachingDisabled() {
+        policy = new ResponseCachingPolicy(0, true, true, false);
+        request = new BasicHttpRequest("GET", "/foo?s=bar");
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(tenSecondsFromNow));
         Assert.assertTrue(policy.isResponseCacheable(request, response));
     }
 
@@ -397,16 +519,34 @@ public class TestResponseCachingPolicy {
         response = new BasicHttpResponse(HttpVersion.HTTP_1_0, HttpStatus.SC_OK, "OK");
         Assert.assertFalse(policy.isResponseCacheable(request, response));
     }
-    
+
     @Test
-    public void getsWithQueryParametersDirectlyFrom1_0OriginsAreNotCacheableEvenWithExpires() {
+    public void getsWithQueryParametersDirectlyFrom1_0OriginsAreNotCacheableEvenWithSetting() {
+        policy = new ResponseCachingPolicy(0, true, true, false);
         request = new BasicHttpRequest("GET", "/foo?s=bar");
         response = new BasicHttpResponse(HttpVersion.HTTP_1_0, HttpStatus.SC_OK, "OK");
-        response.setHeader("Date", formatDate(now));
-        response.setHeader("Expires", formatDate(tenSecondsFromNow));
         Assert.assertFalse(policy.isResponseCacheable(request, response));
     }
-    
+
+    @Test
+    public void getsWithQueryParametersDirectlyFrom1_0OriginsAreCacheableWithExpires() {
+        request = new BasicHttpRequest("GET", "/foo?s=bar");
+        response = new BasicHttpResponse(HttpVersion.HTTP_1_0, HttpStatus.SC_OK, "OK");
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(tenSecondsFromNow));
+        Assert.assertTrue(policy.isResponseCacheable(request, response));
+    }
+
+    @Test
+    public void getsWithQueryParametersDirectlyFrom1_0OriginsCanBeNotCacheableEvenWithExpires() {
+        policy = new ResponseCachingPolicy(0, true, true, false);
+        request = new BasicHttpRequest("GET", "/foo?s=bar");
+        response = new BasicHttpResponse(HttpVersion.HTTP_1_0, HttpStatus.SC_OK, "OK");
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(tenSecondsFromNow));
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
     @Test
     public void getsWithQueryParametersFrom1_0OriginsViaProxiesAreNotCacheable() {
         request = new BasicHttpRequest("GET", "/foo?s=bar");
@@ -415,21 +555,43 @@ public class TestResponseCachingPolicy {
     }
 
     @Test
-    public void getsWithQueryParametersFrom1_0OriginsViaProxiesAreNotCacheableEvenWithExpires() {
+    public void getsWithQueryParametersFrom1_0OriginsViaProxiesAreCacheableWithExpires() {
         request = new BasicHttpRequest("GET", "/foo?s=bar");
-        Date now = new Date();
-        Date tenSecondsFromNow = new Date(now.getTime() + 10 * 1000L);
-        response.setHeader("Date", formatDate(now));
-        response.setHeader("Expires", formatDate(tenSecondsFromNow));
+        final Date now = new Date();
+        final Date tenSecondsFromNow = new Date(now.getTime() + 10 * 1000L);
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(tenSecondsFromNow));
+        response.setHeader("Via", "1.0 someproxy");
+        Assert.assertTrue(policy.isResponseCacheable(request, response));
+    }
+
+    @Test
+    public void getsWithQueryParametersFrom1_0OriginsViaProxiesCanNotBeCacheableEvenWithExpires() {
+        policy = new ResponseCachingPolicy(0, true, true, true);
+        request = new BasicHttpRequest("GET", "/foo?s=bar");
+        final Date now = new Date();
+        final Date tenSecondsFromNow = new Date(now.getTime() + 10 * 1000L);
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(tenSecondsFromNow));
         response.setHeader("Via", "1.0 someproxy");
         Assert.assertFalse(policy.isResponseCacheable(request, response));
     }
-    
+
     @Test
-    public void getsWithQueryParametersFrom1_0OriginsViaExplicitProxiesAreNotCacheableEvenWithExpires() {
+    public void getsWithQueryParametersFrom1_0OriginsViaExplicitProxiesAreCacheableWithExpires() {
         request = new BasicHttpRequest("GET", "/foo?s=bar");
-        response.setHeader("Date", formatDate(now));
-        response.setHeader("Expires", formatDate(tenSecondsFromNow));
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(tenSecondsFromNow));
+        response.setHeader("Via", "HTTP/1.0 someproxy");
+        Assert.assertTrue(policy.isResponseCacheable(request, response));
+    }
+
+    @Test
+    public void getsWithQueryParametersFrom1_0OriginsViaExplicitProxiesCanNotBeCacheableEvenWithExpires() {
+        policy = new ResponseCachingPolicy(0, true, true, true);
+        request = new BasicHttpRequest("GET", "/foo?s=bar");
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(tenSecondsFromNow));
         response.setHeader("Via", "HTTP/1.0 someproxy");
         Assert.assertFalse(policy.isResponseCacheable(request, response));
     }
@@ -438,30 +600,74 @@ public class TestResponseCachingPolicy {
     public void getsWithQueryParametersFrom1_1OriginsVia1_0ProxiesAreCacheableWithExpires() {
         request = new BasicHttpRequest("GET", "/foo?s=bar");
         response = new BasicHttpResponse(HttpVersion.HTTP_1_0, HttpStatus.SC_OK, "OK");
-        response.setHeader("Date", formatDate(now));
-        response.setHeader("Expires", formatDate(tenSecondsFromNow));
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(tenSecondsFromNow));
         response.setHeader("Via", "1.1 someproxy");
         Assert.assertTrue(policy.isResponseCacheable(request, response));
     }
-    
+
     @Test
     public void notCacheableIfExpiresEqualsDateAndNoCacheControl() {
-        response.setHeader("Date", formatDate(now));
-        response.setHeader("Expires", formatDate(now));
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(now));
         response.removeHeaders("Cache-Control");
         Assert.assertFalse(policy.isResponseCacheable(request, response));
     }
 
     @Test
     public void notCacheableIfExpiresPrecedesDateAndNoCacheControl() {
-        response.setHeader("Date", formatDate(now));
-        response.setHeader("Expires", formatDate(sixSecondsAgo));
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Expires", DateUtils.formatDate(sixSecondsAgo));
         response.removeHeaders("Cache-Control");
         Assert.assertFalse(policy.isResponseCacheable(request, response));
     }
 
+    @Test
+    public void test302WithExplicitCachingHeaders() {
+        response.setStatusCode(HttpStatus.SC_MOVED_TEMPORARILY);
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Cache-Control","max-age=300");
+        Assert.assertTrue(policy.isResponseCacheable(request, response));
+    }
+
+    @Test
+    public void test303WithExplicitCachingHeadersUnderDefaultBehavior() {
+        // RFC 2616 says: 303 should not be cached
+        response.setStatusCode(HttpStatus.SC_SEE_OTHER);
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Cache-Control","max-age=300");
+        Assert.assertFalse(policy.isResponseCacheable(request, response));
+    }
+
+    @Test
+    public void test303WithExplicitCachingHeadersWhenPermittedByConfig() {
+        // HTTPbis working group says ok if explicitly indicated by
+        // response headers
+        policy = new ResponseCachingPolicy(0, true, false, true);
+        response.setStatusCode(HttpStatus.SC_SEE_OTHER);
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Cache-Control","max-age=300");
+        Assert.assertTrue(policy.isResponseCacheable(request, response));
+    }
+
+    @Test
+    public void test307WithExplicitCachingHeaders() {
+        response.setStatusCode(HttpStatus.SC_TEMPORARY_REDIRECT);
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Cache-Control","max-age=300");
+        Assert.assertTrue(policy.isResponseCacheable(request, response));
+    }
+
+    @Test
+    public void otherStatusCodesAreCacheableWithExplicitCachingHeaders() {
+        response.setStatusCode(HttpStatus.SC_NOT_FOUND);
+        response.setHeader("Date", DateUtils.formatDate(now));
+        response.setHeader("Cache-Control","max-age=300");
+        Assert.assertTrue(policy.isResponseCacheable(request, response));
+    }
+
     private int getRandomStatus() {
-        int rnd = (new Random()).nextInt(acceptableCodes.length);
+        final int rnd = new Random().nextInt(acceptableCodes.length);
 
         return acceptableCodes[rnd];
     }
