@@ -27,55 +27,46 @@
 
 package org.apache.http.examples.client;
 
-import org.apache.http.Header;
-import org.apache.http.HttpEntity;
 import org.apache.http.HttpHost;
-import org.apache.http.HttpResponse;
-import org.apache.http.client.HttpClient;
+import org.apache.http.client.config.RequestConfig;
+import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.client.methods.HttpGet;
-import org.apache.http.conn.params.ConnRoutePNames;
-import org.apache.http.impl.client.DefaultHttpClient;
+import org.apache.http.impl.client.CloseableHttpClient;
+import org.apache.http.impl.client.HttpClients;
 import org.apache.http.util.EntityUtils;
 
 /**
- * How to send a request via proxy using {@link HttpClient}.
+ * How to send a request via proxy.
  *
  * @since 4.0
  */
 public class ClientExecuteProxy {
 
     public static void main(String[] args)throws Exception {
-        HttpHost proxy = new HttpHost("127.0.0.1", 8080, "http");
-
-        DefaultHttpClient httpclient = new DefaultHttpClient();
+        CloseableHttpClient httpclient = HttpClients.createDefault();
         try {
-            httpclient.getParams().setParameter(ConnRoutePNames.DEFAULT_PROXY, proxy);
+            HttpHost target = new HttpHost("localhost", 443, "https");
+            HttpHost proxy = new HttpHost("127.0.0.1", 8080, "http");
 
-            HttpHost target = new HttpHost("issues.apache.org", 443, "https");
-            HttpGet req = new HttpGet("/");
+            RequestConfig config = RequestConfig.custom()
+                    .setProxy(proxy)
+                    .build();
+            HttpGet request = new HttpGet("/");
+            request.setConfig(config);
 
-            System.out.println("executing request to " + target + " via " + proxy);
-            HttpResponse rsp = httpclient.execute(target, req);
-            HttpEntity entity = rsp.getEntity();
+            System.out.println("Executing request " + request.getRequestLine() + " to " + target + " via " + proxy);
 
-            System.out.println("----------------------------------------");
-            System.out.println(rsp.getStatusLine());
-            Header[] headers = rsp.getAllHeaders();
-            for (int i = 0; i<headers.length; i++) {
-                System.out.println(headers[i]);
+            CloseableHttpResponse response = httpclient.execute(target, request);
+            try {
+                System.out.println("----------------------------------------");
+                System.out.println(response.getStatusLine());
+                EntityUtils.consume(response.getEntity());
+            } finally {
+                response.close();
             }
-            System.out.println("----------------------------------------");
-
-            if (entity != null) {
-                System.out.println(EntityUtils.toString(entity));
-            }
-
         } finally {
-            // When HttpClient instance is no longer needed,
-            // shut down the connection manager to ensure
-            // immediate deallocation of all system resources
-            httpclient.getConnectionManager().shutdown();
+            httpclient.close();
         }
     }
 
-}
\ No newline at end of file
+}
