@@ -29,9 +29,9 @@ package org.apache.http.impl.auth;
 
 import org.apache.http.Header;
 import org.apache.http.HttpRequest;
+import org.apache.http.auth.AUTH;
 import org.apache.http.auth.AuthenticationException;
 import org.apache.http.auth.Credentials;
-import org.apache.http.auth.AUTH;
 import org.apache.http.auth.MalformedChallengeException;
 import org.apache.http.message.BasicHeader;
 import org.apache.http.message.BufferedHeader;
@@ -43,6 +43,7 @@ public class TestRFC2617Scheme {
 
     static class TestAuthScheme extends RFC2617Scheme {
 
+        @Deprecated
         public Header authenticate(
                 final Credentials credentials,
                 final HttpRequest request) throws AuthenticationException {
@@ -65,27 +66,30 @@ public class TestRFC2617Scheme {
 
     @Test
     public void testProcessChallenge() throws Exception {
-        TestAuthScheme authscheme = new TestAuthScheme();
-        Header header = new BasicHeader(
+        final TestAuthScheme authscheme = new TestAuthScheme();
+        final Header header = new BasicHeader(
                 AUTH.WWW_AUTH,
                 "Test realm=\"realm1\", test, test1 =  stuff, test2 =  \"stuff, stuff\", test3=\"crap");
 
         authscheme.processChallenge(header);
 
         Assert.assertEquals("test", authscheme.getSchemeName());
+        Assert.assertEquals("TEST", authscheme.toString());
         Assert.assertEquals("realm1", authscheme.getParameter("realm"));
         Assert.assertEquals(null, authscheme.getParameter("test"));
         Assert.assertEquals("stuff", authscheme.getParameter("test1"));
         Assert.assertEquals("stuff, stuff", authscheme.getParameter("test2"));
         Assert.assertEquals("\"crap", authscheme.getParameter("test3"));
+        Assert.assertEquals(null, authscheme.getParameter(null));
     }
 
     @Test
     public void testProcessChallengeWithLotsOfBlanks() throws Exception {
-        TestAuthScheme authscheme = new TestAuthScheme();
-        CharArrayBuffer buffer = new CharArrayBuffer(32);
+        final TestAuthScheme authscheme = new TestAuthScheme();
+        final CharArrayBuffer buffer = new CharArrayBuffer(32);
         buffer.append(" WWW-Authenticate:    Test       realm=\"realm1\"");
-        Header header = new BufferedHeader(buffer);
+        final Header header = new BufferedHeader(buffer);
+
 
         authscheme.processChallenge(header);
 
@@ -93,24 +97,41 @@ public class TestRFC2617Scheme {
         Assert.assertEquals("realm1", authscheme.getParameter("realm"));
     }
 
+    @Test
+    public void testNullHeader() throws Exception {
+        final TestAuthScheme authscheme = new TestAuthScheme();
+        try {
+            authscheme.processChallenge(null);
+            Assert.fail("IllegalArgumentException should have been thrown");
+        } catch (final IllegalArgumentException ex) {
+        }
+    }
+
     @Test(expected=MalformedChallengeException.class)
     public void testInvalidHeader() throws Exception {
-        TestAuthScheme authscheme = new TestAuthScheme();
-        Header header = new BasicHeader("whatever", "Test realm=\"realm1\"");
+        final TestAuthScheme authscheme = new TestAuthScheme();
+        final Header header = new BasicHeader("whatever", "Test realm=\"realm1\"");
+        authscheme.processChallenge(header);
+    }
+
+    @Test(expected=MalformedChallengeException.class)
+    public void testInvalidSchemeName() throws Exception {
+        final TestAuthScheme authscheme = new TestAuthScheme();
+        final Header header = new BasicHeader(AUTH.WWW_AUTH, "Not-a-Test realm=\"realm1\"");
         authscheme.processChallenge(header);
     }
 
     @Test(expected=MalformedChallengeException.class)
     public void testEmptyHeader() throws Exception {
-        TestAuthScheme authscheme = new TestAuthScheme();
-        Header header = new BasicHeader(AUTH.WWW_AUTH, "Test    ");
+        final TestAuthScheme authscheme = new TestAuthScheme();
+        final Header header = new BasicHeader(AUTH.WWW_AUTH, "Test    ");
         authscheme.processChallenge(header);
     }
 
     @Test(expected=MalformedChallengeException.class)
     public void testInvalidHeaderValue() throws Exception {
-        TestAuthScheme authscheme = new TestAuthScheme();
-        Header header = new BasicHeader("whatever", "whatever");
+        final TestAuthScheme authscheme = new TestAuthScheme();
+        final Header header = new BasicHeader("whatever", "whatever");
         authscheme.processChallenge(header);
     }
 
