@@ -33,37 +33,33 @@ import java.net.ServerSocket;
 import java.net.Socket;
 import java.util.Collections;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import javax.net.ssl.SSLContext;
+import javax.net.ssl.SSLServerSocket;
 import javax.net.ssl.SSLServerSocketFactory;
 
 import org.apache.http.ConnectionReuseStrategy;
 import org.apache.http.HttpResponseFactory;
 import org.apache.http.HttpResponseInterceptor;
 import org.apache.http.HttpServerConnection;
+import org.apache.http.impl.DefaultBHttpServerConnection;
 import org.apache.http.impl.DefaultConnectionReuseStrategy;
 import org.apache.http.impl.DefaultHttpResponseFactory;
-import org.apache.http.impl.DefaultHttpServerConnection;
-import org.apache.http.params.CoreConnectionPNames;
-import org.apache.http.params.HttpParams;
-import org.apache.http.params.CoreProtocolPNames;
-import org.apache.http.params.SyncBasicHttpParams;
-import org.apache.http.protocol.BasicHttpProcessor;
-import org.apache.http.protocol.HttpContext;
 import org.apache.http.protocol.BasicHttpContext;
+import org.apache.http.protocol.HttpContext;
 import org.apache.http.protocol.HttpExpectationVerifier;
 import org.apache.http.protocol.HttpProcessor;
 import org.apache.http.protocol.HttpRequestHandler;
-import org.apache.http.protocol.HttpRequestHandlerRegistry;
 import org.apache.http.protocol.HttpService;
 import org.apache.http.protocol.ImmutableHttpProcessor;
 import org.apache.http.protocol.ResponseConnControl;
 import org.apache.http.protocol.ResponseContent;
 import org.apache.http.protocol.ResponseDate;
 import org.apache.http.protocol.ResponseServer;
+import org.apache.http.protocol.UriHttpRequestHandlerMapper;
+import org.apache.http.util.Asserts;
 
 /**
  * Local HTTP server for tests that require one.
@@ -71,6 +67,8 @@ import org.apache.http.protocol.ResponseServer;
  */
 public class LocalTestServer {
 
+    public final static String ORIGIN = "LocalTestServer/1.1";
+
     /**
      * The local address to bind to.
      * The host is an IP number rather than "localhost" to avoid surprises
@@ -81,13 +79,16 @@ public class LocalTestServer {
         new InetSocketAddress("127.0.0.1", 0);
 
     /** The request handler registry. */
-    private final HttpRequestHandlerRegistry handlerRegistry;
+    private final UriHttpRequestHandlerMapper handlerRegistry;
 
     private final HttpService httpservice;
 
     /** Optional SSL context */
     private final SSLContext sslcontext;
 
+    /** Optional flag whether to force SSL context */
+    private final boolean forceSSLAuth;
+
     /** The server socket, while being served. */
     private volatile ServerSocket servicedSocket;
 
@@ -100,6 +101,8 @@ public class LocalTestServer {
     /** The number of connections this accepted. */
     private final AtomicInteger acceptedConnections = new AtomicInteger(0);
 
+    private volatile int timeout;
+
     /**
      * Creates a new test server.
      *
@@ -110,30 +113,49 @@ public class LocalTestServer {
      *                  server, or <code>null</code> to use
      *                  {@link #newConnectionReuseStrategy() default}
      *                  strategy.
-     * @param params    the parameters to be used by the server, or
-     *                  <code>null</code> to use
-     *                  {@link #newDefaultParams default} parameters
+     * @param responseFactory the response factory to be used by the
+     *                  server, or <code>null</code> to use
+     *                  {@link #newHttpResponseFactory() default} factory.
+     * @param expectationVerifier the expectation verifier. May be
+     *                  <code>null</code>.
      * @param sslcontext optional SSL context if the server is to leverage
      *                   SSL/TLS transport security
+     * @param forceSSLAuth whether or not the server needs to enforce client auth
      */
     public LocalTestServer(
-            final BasicHttpProcessor proc,
+            final HttpProcessor proc,
             final ConnectionReuseStrategy reuseStrat,
             final HttpResponseFactory responseFactory,
             final HttpExpectationVerifier expectationVerifier,
-            final HttpParams params,
-            final SSLContext sslcontext) {
+            final SSLContext sslcontext,
+            final boolean forceSSLAuth) {
         super();
-        this.handlerRegistry = new HttpRequestHandlerRegistry();
+        this.handlerRegistry = new UriHttpRequestHandlerMapper();
         this.workers = Collections.synchronizedSet(new HashSet<Worker>());
         this.httpservice = new HttpService(
             proc != null ? proc : newProcessor(),
             reuseStrat != null ? reuseStrat: newConnectionReuseStrategy(),
             responseFactory != null ? responseFactory: newHttpResponseFactory(),
             handlerRegistry,
-            expectationVerifier,
-            params != null ? params : newDefaultParams());
+            expectationVerifier);
         this.sslcontext = sslcontext;
+        this.forceSSLAuth = forceSSLAuth;
+    }
+
+    public LocalTestServer(
+            final HttpProcessor proc,
+            final ConnectionReuseStrategy reuseStrat) {
+        this(proc, reuseStrat, null, null, null, false);
+    }
+
+    /**
+     * Creates a new test server with SSL/TLS encryption.
+     *
+     * @param sslcontext SSL context
+     * @param forceSSLAuth whether or not the server needs to enforce client auth
+     */
+    public LocalTestServer(final SSLContext sslcontext, final boolean forceSSLAuth) {
+        this(null, null, null, null, sslcontext, forceSSLAuth);
     }
 
     /**
@@ -142,23 +164,7 @@ public class LocalTestServer {
      * @param sslcontext SSL context
      */
     public LocalTestServer(final SSLContext sslcontext) {
-        this(null, null, null, null, null, sslcontext);
-    }
-
-    /**
-     * Creates a new test server.
-     *
-     * @param proc      the HTTP processors to be used by the server, or
-     *                  <code>null</code> to use a
-     *                  {@link #newProcessor default} processor
-     * @param params    the parameters to be used by the server, or
-     *                  <code>null</code> to use
-     *                  {@link #newDefaultParams default} parameters
-     */
-    public LocalTestServer(
-            BasicHttpProcessor proc,
-            HttpParams params) {
-        this(proc, null, null, null, params, null);
+        this(null, null, null, null, sslcontext, false);
     }
 
     /**
@@ -170,36 +176,18 @@ public class LocalTestServer {
         return new ImmutableHttpProcessor(
                 new HttpResponseInterceptor[] {
                         new ResponseDate(),
-                        new ResponseServer(),
+                        new ResponseServer(ORIGIN),
                         new ResponseContent(),
                         new ResponseConnControl()
                 });
     }
 
-
-    /**
-     * Obtains a set of reasonable default parameters for a server.
-     *
-     * @return  default parameters
-     */
-    protected HttpParams newDefaultParams() {
-        HttpParams params = new SyncBasicHttpParams();
-        params
-            .setIntParameter(CoreConnectionPNames.SO_TIMEOUT, 60000)
-            .setIntParameter(CoreConnectionPNames.SOCKET_BUFFER_SIZE, 8 * 1024)
-            .setBooleanParameter(CoreConnectionPNames.STALE_CONNECTION_CHECK, false)
-            .setBooleanParameter(CoreConnectionPNames.TCP_NODELAY, true)
-            .setParameter(CoreProtocolPNames.ORIGIN_SERVER,
-                          "LocalTestServer/1.1");
-        return params;
-    }
-
     protected ConnectionReuseStrategy newConnectionReuseStrategy() {
-        return new DefaultConnectionReuseStrategy();
+        return DefaultConnectionReuseStrategy.INSTANCE;
     }
 
     protected HttpResponseFactory newHttpResponseFactory() {
-        return new DefaultHttpResponseFactory();
+        return DefaultHttpResponseFactory.INSTANCE;
     }
 
     /**
@@ -223,39 +211,48 @@ public class LocalTestServer {
         handlerRegistry.register("/random/*", new RandomHandler());
     }
 
-
     /**
      * Registers a handler with the local registry.
      *
      * @param pattern   the URL pattern to match
      * @param handler   the handler to apply
      */
-    public void register(String pattern, HttpRequestHandler handler) {
+    public void register(final String pattern, final HttpRequestHandler handler) {
         handlerRegistry.register(pattern, handler);
     }
 
-
     /**
      * Unregisters a handler from the local registry.
      *
      * @param pattern   the URL pattern
      */
-    public void unregister(String pattern) {
+    public void unregister(final String pattern) {
         handlerRegistry.unregister(pattern);
     }
 
+    public int getTimeout() {
+        return timeout;
+    }
+
+    public void setTimeout(final int timeout) {
+        this.timeout = timeout;
+    }
 
     /**
      * Starts this test server.
      */
     public void start() throws Exception {
-        if (servicedSocket != null) {
-            throw new IllegalStateException(this.toString() + " already running");
-        }
-        ServerSocket ssock;
+        Asserts.check(servicedSocket == null, "Already running");
+        final ServerSocket ssock;
         if (sslcontext != null) {
-            SSLServerSocketFactory sf = sslcontext.getServerSocketFactory();
-            ssock = sf.createServerSocket();
+            final SSLServerSocketFactory sf = sslcontext.getServerSocketFactory();
+            final SSLServerSocket sslsock = (SSLServerSocket) sf.createServerSocket();
+            if (forceSSLAuth) {
+                sslsock.setNeedClientAuth(true);
+            } else {
+                sslsock.setWantClientAuth(true);
+            }
+            ssock = sslsock;
         } else {
             ssock = new ServerSocket();
         }
@@ -276,19 +273,18 @@ public class LocalTestServer {
         if (servicedSocket == null) {
             return; // not running
         }
-        ListenerThread t = listenerThread;
+        final ListenerThread t = listenerThread;
         if (t != null) {
             t.shutdown();
         }
         synchronized (workers) {
-            for (Iterator<Worker> it = workers.iterator(); it.hasNext(); ) {
-                Worker worker = it.next();
+            for (final Worker worker : workers) {
                 worker.shutdown();
             }
         }
     }
 
-    public void awaitTermination(long timeMs) throws InterruptedException {
+    public void awaitTermination(final long timeMs) throws InterruptedException {
         if (listenerThread != null) {
             listenerThread.join(timeMs);
         }
@@ -296,13 +292,14 @@ public class LocalTestServer {
 
     @Override
     public String toString() {
-        ServerSocket ssock = servicedSocket; // avoid synchronization
-        StringBuilder sb = new StringBuilder(80);
+        final ServerSocket ssock = servicedSocket; // avoid synchronization
+        final StringBuilder sb = new StringBuilder(80);
         sb.append("LocalTestServer/");
-        if (ssock == null)
+        if (ssock == null) {
             sb.append("stopped");
-        else
+        } else {
             sb.append(ssock.getLocalSocketAddress());
+        }
         return sb.toString();
     }
 
@@ -312,13 +309,24 @@ public class LocalTestServer {
      * @return the service address
      */
     public InetSocketAddress getServiceAddress() {
-        ServerSocket ssock = servicedSocket; // avoid synchronization
-        if (ssock == null) {
-            throw new IllegalStateException("not running");
-        }
+        final ServerSocket ssock = servicedSocket; // avoid synchronization
+        Asserts.check(ssock != null, "Not running");
         return (InetSocketAddress) ssock.getLocalSocketAddress();
     }
 
+    /**
+     * Creates an instance of {@link DefaultBHttpServerConnection} to be used
+     * in the Worker thread.
+     * <p>
+     * This method can be overridden in a super class in order to provide
+     * a different implementation of the {@link DefaultBHttpServerConnection}.
+     *
+     * @return DefaultBHttpServerConnection.
+     */
+    protected DefaultBHttpServerConnection createHttpServerConnection() {
+      return new DefaultBHttpServerConnection(8 * 1024);
+    }
+
     /**
      * The request listener.
      * Accepts incoming connections and launches a service thread.
@@ -335,22 +343,23 @@ public class LocalTestServer {
         public void run() {
             try {
                 while (!interrupted()) {
-                    Socket socket = servicedSocket.accept();
+                    final Socket socket = servicedSocket.accept();
                     acceptedConnections.incrementAndGet();
-                    DefaultHttpServerConnection conn = new DefaultHttpServerConnection();
-                    conn.bind(socket, httpservice.getParams());
+                    final DefaultBHttpServerConnection conn = createHttpServerConnection();
+                    conn.bind(socket);
+                    conn.setSocketTimeout(timeout);
                     // Start worker thread
-                    Worker worker = new Worker(conn);
+                    final Worker worker = new Worker(conn);
                     workers.add(worker);
                     worker.setDaemon(true);
                     worker.start();
                 }
-            } catch (Exception ex) {
+            } catch (final Exception ex) {
                 this.exception = ex;
             } finally {
                 try {
                     servicedSocket.close();
-                } catch (IOException ignore) {
+                } catch (final IOException ignore) {
                 }
             }
         }
@@ -359,7 +368,7 @@ public class LocalTestServer {
             interrupt();
             try {
                 servicedSocket.close();
-            } catch (IOException ignore) {
+            } catch (final IOException ignore) {
             }
         }
 
@@ -381,18 +390,18 @@ public class LocalTestServer {
 
         @Override
         public void run() {
-            HttpContext context = new BasicHttpContext();
+            final HttpContext context = new BasicHttpContext();
             try {
                 while (this.conn.isOpen() && !Thread.interrupted()) {
                     httpservice.handleRequest(this.conn, context);
                 }
-            } catch (Exception ex) {
+            } catch (final Exception ex) {
                 this.exception = ex;
             } finally {
                 workers.remove(this);
                 try {
                     this.conn.shutdown();
-                } catch (IOException ignore) {
+                } catch (final IOException ignore) {
                 }
             }
         }
@@ -401,7 +410,7 @@ public class LocalTestServer {
             interrupt();
             try {
                 this.conn.shutdown();
-            } catch (IOException ignore) {
+            } catch (final IOException ignore) {
             }
         }
 
