@@ -31,9 +31,14 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 
+import org.apache.http.entity.ContentType;
 import org.apache.http.entity.mime.MIME;
+import org.apache.http.util.Args;
 
 /**
+ * Binary body part backed by an input stream.
+ *
+ * @see org.apache.http.entity.mime.MultipartEntityBuilder
  *
  * @since 4.0
  */
@@ -42,37 +47,46 @@ public class InputStreamBody extends AbstractContentBody {
     private final InputStream in;
     private final String filename;
 
+    /**
+     * @since 4.1
+     *
+     * @deprecated (4.3) use {@link InputStreamBody#InputStreamBody(InputStream, ContentType,
+     *  String)} or {@link org.apache.http.entity.mime.MultipartEntityBuilder}
+     */
+    @Deprecated
     public InputStreamBody(final InputStream in, final String mimeType, final String filename) {
-        super(mimeType);
-        if (in == null) {
-            throw new IllegalArgumentException("Input stream may not be null");
-        }
+        this(in, ContentType.create(mimeType), filename);
+    }
+
+    public InputStreamBody(final InputStream in, final String filename) {
+        this(in, ContentType.DEFAULT_BINARY, filename);
+    }
+
+    /**
+     * @since 4.3
+     */
+    public InputStreamBody(final InputStream in, final ContentType contentType, final String filename) {
+        super(contentType);
+        Args.notNull(in, "Input stream");
         this.in = in;
         this.filename = filename;
     }
 
-    public InputStreamBody(final InputStream in, final String filename) {
-        this(in, "application/octet-stream", filename);
+    /**
+     * @since 4.3
+     */
+    public InputStreamBody(final InputStream in, final ContentType contentType) {
+        this(in, contentType, null);
     }
 
     public InputStream getInputStream() {
         return this.in;
     }
 
-    /**
-     * @deprecated use {@link #writeTo(OutputStream)}
-     */
-    @Deprecated
-    public void writeTo(final OutputStream out, int mode) throws IOException {
-        writeTo(out);
-    }
-
     public void writeTo(final OutputStream out) throws IOException {
-        if (out == null) {
-            throw new IllegalArgumentException("Output stream may not be null");
-        }
+        Args.notNull(out, "Output stream");
         try {
-            byte[] tmp = new byte[4096];
+            final byte[] tmp = new byte[4096];
             int l;
             while ((l = this.in.read(tmp)) != -1) {
                 out.write(tmp, 0, l);
@@ -87,10 +101,6 @@ public class InputStreamBody extends AbstractContentBody {
         return MIME.ENC_BINARY;
     }
 
-    public String getCharset() {
-        return null;
-    }
-
     public long getContentLength() {
         return -1;
     }
